"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configSchema = void 0;
const zod_1 = require("zod");
exports.configSchema = zod_1.z
    .object({
    debug: zod_1.z
        .boolean({
        message: "If included, debug must be either 'true' or 'false'",
    })
        .optional(),
    destination: zod_1.z.string().regex(
    // biome-ignore lint/suspicious/noControlCharactersInRegex: <explanation>
    /^(?!\/)(?!.*\/\/)([^<>:"\\|?*\x00-\x1F\/]+\/)*[^<>:"\\|?*\x00-\x1F\/]*\.(md|markdown)$/, {
        message: "Destination must be a valid markdown file name",
    }),
    excludes: zod_1.z
        .array(zod_1.z.string().regex(/^(?:\.[a-zA-Z0-9_\-\/]+\/)*[a-zA-Z0-9_\-]+\.bru$/, {
        message: "Excludes must be an array of valid bru files",
    }))
        .optional(),
    force: zod_1.z
        .boolean({
        message: "If included, force must be either 'true' or 'false'",
    })
        .optional(),
    header: zod_1.z
        .string()
        .regex(/^(?:[a-zA-Z0-9_\-\/]+\/)*[a-zA-Z0-9_\-]+\.md$/, {
        message: "Header must be a valid markdown file name",
    })
        .optional(),
    logOptions: zod_1.z.object({
        silent: zod_1.z
            .boolean({
            message: "If included, silent must be either 'true' or 'false'",
        })
            .optional(),
        verbose: zod_1.z
            .boolean({
            message: "If included, verbose must be either 'true' or 'false'",
        })
            .optional(),
    }),
    source: zod_1.z
        .string()
        .regex(/^(\.{0,2}\/?([a-zA-Z0-9_\-]+\/)*[a-zA-Z0-9_\-]+\/?)$/, {
        message: "Source must be a valid folder name",
    }),
    tail: zod_1.z
        .string()
        .regex(/^(?:[a-zA-Z0-9_\-\/]+\/)*[a-zA-Z0-9_\-]+\.md$/, {
        message: "Tail must be a valid markdown file name",
    })
        .optional(),
})
    .strict({
    message: "Unsupported key(s) in configuration file",
});
//# sourceMappingURL=schema.js.map